/******************************************************************************
 * JibsToggle.java - A map of player config settings that can be toggled.
 * $Id: JibsToggle.java,v 1.4 2011/06/18 06:30:23 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: JibsToggle.java,v $
 * Revision 1.4  2011/06/18 06:30:23  dick
 * Have only one array of map strings and everyone can use it.
 * Use constants instead of numbers for indexing that array.
 *
 * Revision 1.3  2011/06/05 06:03:55  dick
 * whitespace.
 *
 * Revision 1.2  2011/05/31 15:25:49  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.util;

import org.apache.log4j.Logger;

import java.util.HashMap;
import java.util.Map;

/** A map of player config settings that can be toggled. 
 * 
 * @author Dick Balaska
 * @author Axel Leucht
 * @since 2005/03/30
 * @version $Revision: 1.4 $ <br> $Date: 2011/06/18 06:30:23 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/util/JibsToggle.java">cvs JibsToggle.java</a>
 */
public class JibsToggle {
	private static Logger logger = Logger.getLogger(JibsToggle.class);
	private Map<String, Boolean> toggleMap;

	public static final int tAllowPip	= 0;
	public static final int tAutoboard	= 1;
	public static final int tAutodouble	= 2;
	public static final int tAutomove	= 3;
	public static final int tAway		= 4;
	public static final int tBell		= 5;
	public static final int tCrawford	= 6;
	public static final int tDouble		= 7;
	public static final int tGreedy		= 8;
	public static final int tMoreboards	= 9;
	public static final int tMoves		= 10;
	public static final int tNotify		= 11;
	public static final int tRatings	= 12;
	public static final int tReady		= 13;
	public static final int tReport		= 14;
	public static final int tSilent		= 15;
	public static final int tTelnet		= 16;
	public static final int tWatch		= 17;
	public static final int tWrap		= 18;

	/** An array of all of the possible names of a toggle */
	public static String[] toggleNames = {
			"allowpip", "autoboard", "autodouble", "automove",
			"away", "bell", "crawford", "double",
			"greedy", "moreboards", "moves", "notify",
			"ratings", "ready",	"report", "silent",
			"telnet", "watch", "wrap"
	};

	/** Get the default values for a new Player
	 * @return The jIBS toggles defaults for a new Player
	 */
	public static String getDefaultValues() {
		return("1101001101010110100");
	}

	/** Construct a JibsToggle with these initial settings
	 * @param toggles The String of toggles.  Default is: ???
	 */
	public JibsToggle(String toggles) {
		toggleMap = new HashMap<String, Boolean>();


		for (int i = 0; i < toggles.length(); i++) {
			char value = toggles.charAt(i);

			if (value == '0') {
				toggleMap.put(toggleNames[i], Boolean.FALSE);
			} else {
				toggleMap.put(toggleNames[i], Boolean.TRUE);
			}
		}
	}

	/** Get the value of a toggle.
	 * @param key The toggle to query
	 * @return Value of the toggle.  If not found, log a warning and return false.
	 */
	public Boolean get(String key) {
		Object obj = toggleMap.get(key);

		if (obj != null) {
			if (obj instanceof Boolean) {
				return (Boolean) obj;
			}

			return Boolean.FALSE;
		}

		logger.warn("JibsToggle:get(" + key + ") not defined.");

		return Boolean.FALSE;
	}

	/** Set the value of a toggle
	 * @param key The toggle to set.  Note: no validation that it is a "legal" toggle
	 * @param value true or false
	 */
	public void set(String key, Boolean value) {
		toggleMap.put(key, value);
	}

	/** Get a reference to our entire map of toggles
	 * @return The toggleMap
	 */
	public Map<String, Boolean> getToggleMap() {
		return toggleMap;
	}

	/** Return the tight string of the values of each toggle.
	 * (The same string passed in the constructor)
	 * @return something like: "101010101"
	 */
	public String toString() {
		StringBuffer buffer = new StringBuffer();

		for (int i = 0; i < toggleNames.length; i++) {
			Boolean bValue = toggleMap.get(toggleNames[i]);

			if (bValue) {
				buffer.append("1");
			} else {
				buffer.append("0");
			}
		}

		return buffer.toString();
	}
}
